@@ -1,10 +1,11 @@
 from youtubesearchpython.__future__.search import Search, VideosSearch, ChannelsSearch, PlaylistsSearch, CustomSearch, ChannelSearch
-from youtubesearchpython.__future__.extras import Video, Playlist, Suggestions, Hashtag
+from youtubesearchpython.__future__.extras import Video, Playlist, Suggestions, Hashtag, Comments
 from youtubesearchpython.__future__.streamurlfetcher import StreamURLFetcher
+from youtubesearchpython.core.utils import *
 from youtubesearchpython.core.constants import *
 
 
 __title__        = 'youtube-search-python'
-__version__      = '1.4.5'
+__version__      = '1.6.2'
 __author__       = 'alexmercerind'
 __license__      = 'MIT'
